/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.gui.combobox;

import java.awt.event.KeyListener;
import javax.swing.ComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JTextField;
import javax.swing.event.DocumentListener;
/** In order for a JComboBox to perform the way Gatherer requires, ie firing
 * a DocumentEvent of some form whenever the user edits the content of the
 * currently selected item, we need to subclass JComboBox and build a version
 * which adds a DocumentListener to the JTextField within the combobox not to
 * the combobox itself. The same deal applies for KeyListeners.
 */
public class GComboBox
	 extends JComboBox {

	 private JTextField text;

	 public GComboBox() {
		  super();
		  text = (JTextField) this.getEditor().getEditorComponent();
	 }

	 public GComboBox(ComboBoxModel model) {
		  super(model);
		  text = (JTextField) this.getEditor().getEditorComponent();
	 }	 

	 public void addDocumentListener(DocumentListener listener) {
		  if(text != null) text.getDocument().addDocumentListener(listener);
	 }

	 public void addKeyListener(KeyListener listener) {
		  if(text != null) text.addKeyListener(listener);
	 }

	 public String getText() {
		  if(text != null) {
				return text.getText();
		  }
		  GComboBoxModel model = (GComboBoxModel)this.getModel();
		  return (String)model.getSelectedItem();
	 }

	 public void setText(String value) {
		  if(text != null) text.setText(value);
	 }

	 public void removeDocumentListener(DocumentListener listener) {
		  if(text != null) text.getDocument().removeDocumentListener(listener);
	 }

	 public void removeKeyListener(KeyListener listener) {
		  if(text != null) text.removeKeyListener(listener);
	 }
}
